@@ -18,6 +18,9 @@ class Plugin::Twitter::Message < Diva::Model
     %r[\Ahttp://favstar\.fm/users/(?<screen_name>[a-zA-Z0-9_]+)/status/(?<id>\d+)], # Hey, Favstar. Ban stop me premiamu!
     %r[\Ahttp://aclog\.koba789\.com/i/(?<id>\d+)] # Hey, Twitter. Please BAN me rhenium!
   ).freeze
+  MentionMatcher = /(?:@|＠|〄|☯|⑨|♨)([a-zA-Z0-9_]+)/.freeze
+  DESCRIPTION_UNESCAPE_RULE = {'&gt;' => '>', '&lt;' => '<', '&amp;' => '&'}.to_proc
+  DESCRIPTION_UNESCAPE_REGEXP = /&(?:gt|lt|amp);/.freeze
 
   extend Gem::Deprecate
   include Diva::Model::Identity
@@ -56,7 +59,6 @@ class Plugin::Twitter::Message < Diva::Model
   field.time   :created                             # posted time
   field.time   :modified                            # updated time
 
-  entity_class Diva::Entity::ExtendedTwitterEntity
   handle PermalinkMatcher do |uri|
     match = PermalinkMatcher.match(uri.to_s)
     notice match.inspect
@@ -137,6 +139,7 @@ class Plugin::Twitter::Message < Diva::Model
 
   # この投稿のお気に入り状態を返す。お気に入り状態だった場合にtrueを返す
   def favorite?(user_or_world=Service.primary)
+    return unless user_or_world
     case user_or_world.class.slug
     when :twitter_user
       favorited_by.include?(user_or_world)
@@ -153,20 +156,20 @@ class Plugin::Twitter::Message < Diva::Model
   # この投稿にリプライする権限があればtrueを返す
   def repliable?(world=nil)
     world, = Plugin.filtering(:world_current, nil) unless world
-    world.class.slug == :twitter
+    world.class.slug == :twitter if world
   end
 
   # この投稿をお気に入りに追加する権限があればtrueを返す
   def favoritable?(world=nil)
     world, = Plugin.filtering(:world_current, nil) unless world
-    world.class.slug == :twitter
+    world.class.slug == :twitter if world
   end
   alias favoriable? favoritable?
 
   # この投稿をリツイートする権限があればtrueを返す
   def retweetable?(world=nil)
     world, = Plugin.filtering(:world_current, nil) unless world
-    world.class.slug == :twitter and not protected?
+    world.class.slug == :twitter and not protected? if world
   end
 
   # この投稿を削除する権限があればtrueを返す
@@ -222,7 +225,7 @@ class Plugin::Twitter::Message < Diva::Model
       self[:receiver] = parallel{
         self[:receiver] = Plugin::Twitter::User.findbyid(receiver_id) }
     else
-      match = Diva::Entity::BasicTwitterEntity::MentionMatcher.match(self[:message].to_s)
+      match = MentionMatcher.match(self[:message].to_s)
       if match
         result = Plugin::Twitter::User.findbyidname(match[1])
         self[:receiver] = result if result end end end
@@ -238,7 +241,7 @@ class Plugin::Twitter::Message < Diva::Model
   # ==== Return
   # 宛てられたユーザの idname(screen_name) の配列
   def receive_user_screen_names
-    self[:message].to_s.scan(Diva::Entity::BasicTwitterEntity::MentionMatcher).map(&:first) end
+    self[:message].to_s.scan(MentionMatcher).map(&:first) end
 
   # 自分がこのMessageにリプライを返していればtrue
   def mentioned_by_me?
@@ -633,6 +636,7 @@ class Plugin::Twitter::Message < Diva::Model
   def body
     self[:message].to_s.freeze
   end
+  alias_method :description, :body
 
   # Message#body と同じだが、投稿制限文字数を超えていた場合には、収まるように末尾を捨てる。
   def to_s
@@ -655,7 +659,7 @@ class Plugin::Twitter::Message < Diva::Model
 
   # 本文を人間に読みやすい文字列に変換する
   def to_show
-    @to_show ||= body.gsub(/&(gt|lt|quot|amp);/){|m| {'gt' => '>', 'lt' => '<', 'quot' => '"', 'amp' => '&'}[$1] }.freeze end
+    @to_show ||= body.gsub(DESCRIPTION_UNESCAPE_REGEXP, &DESCRIPTION_UNESCAPE_RULE).freeze end
 
   # このMessageのパーマリンクを取得する
   # ==== Return
@@ -668,11 +672,6 @@ class Plugin::Twitter::Message < Diva::Model
   alias :parma_link :perma_link
   deprecate :parma_link, "perma_link", 2016, 12
 
-  # :nodoc:
-  def marshal_dump
-    raise RuntimeError, 'Message cannot marshalize'
-  end
-
   # :nodoc:
   def add_favorited_by(user, time=Time.now)
     type_strict user => Plugin::Twitter::User, time => Time
